# hexdoor

[![License](https://img.shields.io/badge/license-WTFPL-ff69b4.svg)](https://github.com/sinofp/hexdoor/blob/master/LICENSE)
![version](https://img.shields.io/badge/version-0.1.0-red.svg)

A `hexyl` clone，temporarily.

### Install

	pip install hexdoor

### Usage

	hexdoor FILE_NAME

### Preview

[![20190214145324.png](https://i.postimg.cc/qBPNFyF8/20190214145324.png)](https://postimg.cc/G9j388d2)

### MISC

The name `hexdoor` is a mix of `hexyl` and `Rohan Kishibe's Stand` because I'm planing to make it an hex EDITOR. But as you can see there's no editor mode yet. XD